==> huaweicloudsdkcbr-3.1.63-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/agent_update_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AgentUpdateReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'agent': 'AgentUpdate'
    }

    attribute_map = {
        'agent': 'agent'
    }

    def __init__(self, agent=None):
        """AgentUpdateReq

        The model defined in huaweicloud sdk

        :param agent: 
        :type agent: :class:`huaweicloudsdkcbr.v1.AgentUpdate`
        """
        
        

        self._agent = None
        self.discriminator = None

        self.agent = agent

    @property
    def agent(self):
        """Gets the agent of this AgentUpdateReq.

        :return: The agent of this AgentUpdateReq.
        :rtype: :class:`huaweicloudsdkcbr.v1.AgentUpdate`
        """
        return self._agent

    @agent.setter
    def agent(self, agent):
        """Sets the agent of this AgentUpdateReq.

        :param agent: The agent of this AgentUpdateReq.
        :type agent: :class:`huaweicloudsdkcbr.v1.AgentUpdate`
        """
        self._agent = agent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentUpdateReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbr-3.1.157-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/agent_update_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AgentUpdateReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'agent': 'AgentUpdate'
    }

    attribute_map = {
        'agent': 'agent'
    }

    def __init__(self, agent=None):
        r"""AgentUpdateReq

        The model defined in huaweicloud sdk

        :param agent: 
        :type agent: :class:`huaweicloudsdkcbr.v1.AgentUpdate`
        """
        
        

        self._agent = None
        self.discriminator = None

        self.agent = agent

    @property
    def agent(self):
        r"""Gets the agent of this AgentUpdateReq.

        :return: The agent of this AgentUpdateReq.
        :rtype: :class:`huaweicloudsdkcbr.v1.AgentUpdate`
        """
        return self._agent

    @agent.setter
    def agent(self, agent):
        r"""Sets the agent of this AgentUpdateReq.

        :param agent: The agent of this AgentUpdateReq.
        :type agent: :class:`huaweicloudsdkcbr.v1.AgentUpdate`
        """
        self._agent = agent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentUpdateReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
